// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
package org.openqa.selenium.bidi.log;

import org.openqa.selenium.internal.Require;

public class FilterBy {

  private final LogLevel level;

  private FilterBy(LogLevel logLevel) {
    this.level = Require.nonNull("Log level", logLevel);
  }

  public static FilterBy logLevel(LogLevel logLevel) {
    return new FilterBy(logLevel);
  }

  public LogLevel getLevel() {
    return level;
  }

  public boolean matches(BaseLogEntry entry) {
    return entry.getLevel() == level;
  }
}
